@@ -19,6 +19,7 @@ use WebGUI::International;
 use WebGUI::Search;
 use WebGUI::Form;
 use WebGUI::HTML;
+use WebGUI::ICal;
 use WebGUI::DateTime;
 use Class::C3;
 
@@ -273,7 +274,7 @@ sub definition {
                     label       => $i18n->get('Feed URL'),
                 },
                 {
-                    name        => 'status',
+                    name        => 'lastResult',
                     type        => 'readonly',
                     label       => $i18n->get('434','WebGUI'),
                 },
@@ -343,10 +344,6 @@ The date this feed was added, or edited last.
 
 The results of what happened the last time this feed was accessed to pull iCal.
 
-=head4 feedType
-
-What kind of feed this is.
-
 =cut
 
 sub addFeed {
@@ -868,6 +865,17 @@ sub processPropertiesFromFormPost {
         $self->createSubscriptionGroup();
     }
 
+    my @feeds = @{ $self->getFeeds };
+    foreach my $feed (@feeds) {
+        if ($feed->{lastUpdated} eq 'new') {
+            $feed->{lastUpdated} = 'never';
+        }
+        if ($feed->{lastResult} eq 'new') {
+            $feed->{lastResult} = '';
+        }
+        $self->setFeed($feed->{feedId}, $feed);
+    }
+
     return;
 }
 
@@ -1736,97 +1744,20 @@ sub www_ical {
         $dt_end = $dt_start->clone->add( seconds => $self->get('icalInterval') );
     }
 
+    my $ical = WebGUI::ICal->new();
+
     # Get all the events we're going to display
     my @events    = $self->getEventsIn($dt_start->toMysql,$dt_end->toMysql);
 
-
-    my $ical    = qq{BEGIN:VCALENDAR\r\n}
-                . qq{PRODID:WebGUI }.$WebGUI::VERSION."-".$WebGUI::STATUS.qq{\r\n}
-                . qq{VERSION:2.0\r\n};
-
-    # VEVENT:
     EVENT: for my $event (@events) {
         next EVENT unless $event->canView();
-        $ical   .= qq{BEGIN:VEVENT\r\n};
-
-        ### UID
-        # Use feed's UID to prevent over-propagation
-        if ($event->get("feedUid")) {
-            $ical       .= qq{UID:}.$event->get("feedUid")."\r\n";
-        }
-        # Create a UID for feeds native to this calendar
-        else {
-            my $domain  = $session->config->get("sitename")->[0];
-            $ical       .= qq{UID:}.$event->get("assetId").'@'.$domain."\r\n";
-        }
-
-        # LAST-MODIFIED (revisionDate)
-        $ical   .= qq{LAST-MODIFIED:}
-                . WebGUI::DateTime->new($self->session, $event->get("revisionDate"))->toIcal
-                . "\r\n";
-
-        # CREATED (creationDate)
-        $ical   .= qq{CREATED:}
-                . WebGUI::DateTime->new($self->session, $event->get("creationDate"))->toIcal
-                . "\r\n";
-
-        # SEQUENCE
-        my $sequenceNumber = $event->get("iCalSequenceNumber");
-        if (defined $sequenceNumber) {
-            $ical   .= qq{SEQUENCE:}
-                    . $event->get("iCalSequenceNumber")
-                    . "\r\n";
-        }
-
-        # DTSTART
-        my $eventStart = $event->getIcalStart;
-        $ical .= 'DTSTART';
-        if ($eventStart !~ /T/) {
-            $ical .= ';VALUE=DATE';
-        }
-        $ical .= ":$eventStart\r\n";
-
-        # DTEND
-        my $eventEnd = $event->getIcalEnd;
-        $ical .= 'DTEND';
-        if ($eventEnd !~ /T/) {
-            $ical .= ';VALUE=DATE';
-        }
-        $ical .= ":$eventEnd\r\n";
-
-        # Summary (the title)
-        # Wrapped at 75 columns
-        $ical   .= $self->wrapIcal("SUMMARY:".$event->get("title"))."\r\n";
-
-        # Description (the text)
-        # Wrapped at 75 columns
-        $ical   .= $self->wrapIcal("DESCRIPTION:".$event->get("description"))."\r\n";
-
-        # Location (the text)
-        # Wrapped at 75 columns
-        $ical   .= $self->wrapIcal("LOCATION:".$event->get("location"))."\r\n";
-
-        # X-WEBGUI lines
-        if ($event->get("groupIdView")) {
-            $ical   .= "X-WEBGUI-GROUPIDVIEW:".$event->get("groupIdView")."\r\n";
-        }
-        if ($event->get("groupIdEdit")) {
-            $ical   .= "X-WEBGUI-GROUPIDEDIT:".$event->get("groupIdEdit")."\r\n";
-        }
-        $ical   .= "X-WEBGUI-URL:".$event->get("url")."\r\n";
-        $ical   .= "X-WEBGUI-MENUTITLE:".$event->get("menuTitle")."\r\n"; 
-
-        $ical   .= qq{END:VEVENT\r\n};
+        $event->add_to_calendar($ical);
     }
-    # ENDVEVENT
-
-    $ical       .= qq{END:VCALENDAR\r\n};
-
 
     # Set mime of text/icalendar
     #$self->session->http->setMimeType("text/plain");
     $self->session->http->setFilename("feed.ics","text/calendar");
-    return $ical;
+    return $ical->as_string;
 }
 
 #----------------------------------------------------------------------------
